==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/dip/dip-collection-of-ci.js <==
import {Action, ElementUtil, Expectation} from 'protractor-base-dsl';
import WidgetAutocomplete from '../widget/widget-autocomplete';

export const createFunctions = (rootElement) => {
    const itemSelector = (itemNumber) =>
        ElementUtil.elementFinder(rootElement)
            .element(By.css(`.xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`));

    const closeSymbolElement = (itemNumber) =>
        itemSelector(itemNumber).element(By.css('.xl-react-btn-close'));

    const clearFilter = () => {
        const filterClearSelector = '.testComponent .xl-react-widget-filter .xl-react-btn-close';
        return Action.click(filterClearSelector);
    };

    const expectInvalidItem = (itemNumber) => {
        Expectation.present(itemSelector(itemNumber).element(By.css('.ui-sortable-handle-invalid')));
    };

    const expectValidItem = (itemNumber) => {
        Expectation.notPresent(itemSelector(itemNumber).element(By.css('.ui-sortable-handle-invalid')));
    };

    const expectFilterEnabled = () =>
        Expectation.enabled('.testComponent .xl-react-widget-filter');

    const expectSelectedItemToEqual = (itemNumber, value) =>
        Expectation.attributeContainsValue(itemSelector(itemNumber), 'data-id', value);

    const expectClearIconOfItemToBePresent = (itemNumber) =>
        Expectation.present(closeSymbolElement(itemNumber));

    const expectClearIconOfItemToBeNotPresent = (itemNumber) =>
        Expectation.notPresent(closeSymbolElement(itemNumber));

    const expectComponentEnabled = () => {
        WidgetAutocomplete.expectEnabled();
        expectFilterEnabled();
        return expectClearIconOfItemToBePresent(1);
    };

    const expectComponentDisabled = () => {
        WidgetAutocomplete.expectDisabled();
        expectFilterEnabled();
        return expectClearIconOfItemToBeNotPresent(1);
    };

    const expectSelectedItemNotPresent = (itemNumber) =>
        Expectation.notPresent(itemSelector(itemNumber));

    const removeSelectedItem = (itemNumber) =>
        Action.click(closeSymbolElement(itemNumber));

    const setFilter = (value) => {
        const filterSelector = '.testComponent .xl-react-widget-filter input';
        return Action.typeText(filterSelector, value);
    };

    return {
        clearFilter,
        expectComponentDisabled,
        expectComponentEnabled,
        expectFilterEnabled,
        expectInvalidItem,
        expectSelectedItemNotPresent,
        expectSelectedItemToEqual,
        expectClearIconOfItemToBePresent,
        expectClearIconOfItemToBeNotPresent,
        expectValidItem,
        removeSelectedItem,
        setFilter
    };
};

==> xl-react-components-0.21.9.tgz: package/tests/e2e/dsl/component/dip/dip-collection-of-ci.js <==
import {Action, ElementUtil, Expectation} from 'protractor-base-dsl';
import WidgetAutocomplete from '../widget/widget-autocomplete';

export const createFunctions = (rootElement) => {
    const itemSelector = (itemNumber) =>
        ElementUtil.elementFinder(rootElement)
            .element(By.css(`.xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`));

    const closeSymbolElement = (itemNumber) =>
        itemSelector(itemNumber).element(By.css('.close-icon'));

    const clearFilter = () => {
        const filterClearSelector = '.testComponent .xl-react-widget-filter .close-icon';
        return Action.click(filterClearSelector);
    };

    const expectInvalidItem = (itemNumber) => {
        Expectation.present(itemSelector(itemNumber).element(By.css('.warning-icon')));
    };

    const expectValidItem = (itemNumber) => {
        Expectation.notPresent(itemSelector(itemNumber).element(By.css('.warning-icon')));
    };

    const expectFilterEnabled = () =>
        Expectation.enabled('.testComponent .xl-react-widget-filter');

    const expectSelectedItemToEqual = (itemNumber, value) =>
        Expectation.attributeContainsValue(itemSelector(itemNumber), 'data-value', value);

    const expectClearIconOfItemToBePresent = (itemNumber) =>
        Expectation.present(closeSymbolElement(itemNumber));

    const expectClearIconOfItemToBeNotPresent = (itemNumber) =>
        Expectation.notPresent(closeSymbolElement(itemNumber));

    const expectComponentEnabled = () => {
        WidgetAutocomplete.expectEnabled();
        expectFilterEnabled();
        return expectClearIconOfItemToBePresent(1);
    };

    const expectComponentDisabled = () => {
        WidgetAutocomplete.expectDisabled();
        expectFilterEnabled();
        return expectClearIconOfItemToBeNotPresent(1);
    };

    const expectSelectedItemNotPresent = (itemNumber) =>
        Expectation.notPresent(itemSelector(itemNumber));

    const removeSelectedItem = (itemNumber) =>
        Action.click(closeSymbolElement(itemNumber));

    const setFilter = (value) => {
        const filterSelector = '.testComponent .xl-react-widget-filter input';
        return Action.typeText(filterSelector, value);
    };

    return {
        clearFilter,
        expectComponentDisabled,
        expectComponentEnabled,
        expectFilterEnabled,
        expectInvalidItem,
        expectSelectedItemNotPresent,
        expectSelectedItemToEqual,
        expectClearIconOfItemToBePresent,
        expectClearIconOfItemToBeNotPresent,
        expectValidItem,
        removeSelectedItem,
        setFilter
    };
};
